==> haskell-aeson-pretty-0.8.7-83-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-pretty
version: 0.8.7
id: aeson-pretty-0.8.7-838zED1kTY32KvMOfvofJe
key: aeson-pretty-0.8.7-838zED1kTY32KvMOfvofJe
license: BSD-3-Clause
copyright: Copyright 2011 Falko Peters
maintainer: Falko Peters <falko.peters@gmail.com>
author: Falko Peters <falko.peters@gmail.com>
stability: experimental
homepage: http://github.com/informatikr/aeson-pretty
synopsis: JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.
    .
    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.
    .
    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this
    .
    > cabal install -flib-only aeson-pretty
    .
    the command-line tool will NOT be installed.
category: Text, Web, JSON, Pretty Printer
abi: 19451d6bdaa40e2fc147d28e03c911f0
exposed: True
exposed-modules:
    Data.Aeson.Encode.Pretty
import-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-pretty-0.8.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-pretty-0.8.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aeson-pretty-0.8.7
hs-libraries: HSaeson-pretty-0.8.7-838zED1kTY32KvMOfvofJe
depends:
    aeson-1.4.4.0-HZF4dQ7ymfT471uy0aBwyJ base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock
haddock-html: /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-pretty-0.8.7-84-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-pretty
version: 0.8.7
id: aeson-pretty-0.8.7-Gzzxu7OafBr8Kxr4rQBafo
key: aeson-pretty-0.8.7-Gzzxu7OafBr8Kxr4rQBafo
license: BSD-3-Clause
copyright: Copyright 2011 Falko Peters
maintainer: Falko Peters <falko.peters@gmail.com>
author: Falko Peters <falko.peters@gmail.com>
stability: experimental
homepage: http://github.com/informatikr/aeson-pretty
synopsis: JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.
    .
    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.
    .
    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this
    .
    > cabal install -flib-only aeson-pretty
    .
    the command-line tool will NOT be installed.
category: Text, Web, JSON, Pretty Printer
abi: 68cc975679c7252dd838cf3f66b2dbb6
exposed: True
exposed-modules:
    Data.Aeson.Encode.Pretty
import-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-pretty-0.8.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-pretty-0.8.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aeson-pretty-0.8.7
hs-libraries: HSaeson-pretty-0.8.7-Gzzxu7OafBr8Kxr4rQBafo
depends:
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock
haddock-html: /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
